==> ktorrent-3.2.2.tar.xz: ktorrent-3.2.2/plugins/bwscheduler/bwprefpage.cpp <==
/***************************************************************************
 *   Copyright (C) 2008 by Joris Guisson and Ivan Vasic                    *
 *   joris.guisson@gmail.com                                               *
 *   ivasic@gmail.com                                                      *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
 ***************************************************************************/
#include "bwprefpage.h"
#include "bwschedulerpluginsettings.h"

namespace kt
{

	BWPrefPage::BWPrefPage(QWidget* parent) : PrefPageInterface(SchedulerPluginSettings::self(),i18n("Bandwidth Scheduler"),"kt-bandwidth-scheduler",parent)
	{
		setupUi(this);
	}


	BWPrefPage::~BWPrefPage()
	{
	}


	void BWPrefPage::loadDefaults()
	{
	}

	void BWPrefPage::loadSettings()
	{
	}

	void BWPrefPage::updateSettings()
	{
		colorsChanged();
	}

}

==> ktorrent-3.3.4.tar.xz: ktorrent-3.3.4/plugins/bwscheduler/bwprefpage.cpp <==
/***************************************************************************
 *   Copyright (C) 2008 by Joris Guisson and Ivan Vasic                    *
 *   joris.guisson@gmail.com                                               *
 *   ivasic@gmail.com                                                      *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
 ***************************************************************************/
#include "bwprefpage.h"
#include "bwschedulerpluginsettings.h"

namespace kt
{

	BWPrefPage::BWPrefPage(QWidget* parent) : PrefPageInterface(SchedulerPluginSettings::self(),i18n("Bandwidth Scheduler"),"kt-bandwidth-scheduler",parent)
	{
		setupUi(this);
	}


	BWPrefPage::~BWPrefPage()
	{
	}


	void BWPrefPage::loadDefaults()
	{
		kcfg_screensaverDownloadLimit->setEnabled(SchedulerPluginSettings::screensaverLimits());
		kcfg_screensaverUploadLimit->setEnabled(SchedulerPluginSettings::screensaverLimits());
	}

	void BWPrefPage::loadSettings()
	{
		kcfg_screensaverDownloadLimit->setEnabled(SchedulerPluginSettings::screensaverLimits());
		kcfg_screensaverUploadLimit->setEnabled(SchedulerPluginSettings::screensaverLimits());
	}

	void BWPrefPage::updateSettings()
	{
		colorsChanged();
	}

}
